@@ -5,7 +5,7 @@ package Lingua::Translit::Tables;
 #   Alex Linke <alinke@lingua-systems.com>
 #   Rona Linke <rlinke@lingua-systems.com>
 # Copyright (C) 2009-2016 Lingua-Systems Software GmbH
-# Copyright (C) 2016 Netzum Sorglos, Lingua-Systems Software GmbH
+# Copyright (C) 2016-2017 Netzum Sorglos, Lingua-Systems Software GmbH
 #
 
 use strict;
@@ -14,7 +14,7 @@ use utf8;
 
 require 5.008;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 use Carp;
 
@@ -210,6 +210,12 @@ Latin with support for Old Russian (pre 1918), Russian
 I<GOST 7.79 UKR>, reversible, GOST 7.79:2000 (table B), Cyrillic to Latin,
 Ukrainian
 
+I<BGN/PCGN RUS Standard>, not reversible, BGN/PCGN:1947 (Standard Variant),
+Cyrillic to Latin, Russian
+
+I<BGN/PCGN RUS Strict>, not reversible, BGN/PCGN:1947 (Strict Variant),
+Cyrillic to Latin, Russian
+
 =item Greek
 
 I<ISO 843>, not reversible, ISO 843:1997, Greek to Latin
@@ -288,6 +294,9 @@ table.
 Thanks to Philip Kime for contributing the "IAST Devanagari" and "Devanagari
 IAST" transliteration tables.
 
+Thanks to Nikola Lečić for contributing the "BGN/PCGN RUS Standard" and
+"BGN/PCGN RUS Strict" transliteration tables.
+
 =head1 AUTHORS
 
 Alex Linke <alinke@netzum-sorglos.de>
@@ -300,7 +309,7 @@ Copyright (C) 2007-2008 Alex Linke and Rona Linke
 
 Copyright (C) 2009-2016 Lingua-Systems Software GmbH
 
-Copyright (C) 2016 Netzum Sorglos, Lingua-Systems Software GmbH
+Copyright (C) 2016-2017 Netzum Sorglos, Lingua-Systems Software GmbH
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
